@@ -48,7 +48,6 @@
 #include <kactioncollection.h>
 
 #include <KLocalizedString>
-#include <KMessageBox>
 
 #include <QtCore/QPointer>
 #include <QItemSelectionModel>
@@ -337,7 +336,7 @@ public:
             bool allMarkedAsUnread = true;
             bool allMarkedAsActionItem = true;
 
-            foreach (const Akonadi::Item &item, selectedItems) {
+            for (const Akonadi::Item &item : selectedItems) {
                 Akonadi::MessageStatus status;
                 status.setStatusFromFlags(item.flags());
                 if (!status.isImportant()) {
@@ -449,20 +448,24 @@ public:
                 }
             }
         }
+        QAction *action = nullptr;
         if (isSystemFolder) {
-            if (mGenericManager->action(StandardActionManager::DeleteCollections)) {
-                mGenericManager->action(StandardActionManager::DeleteCollections)->setEnabled(false);
+            action = mGenericManager->action(StandardActionManager::DeleteCollections);
+            if (action) {
+                action->setEnabled(false);
             }
         }
 
-        if (mActions.contains(Akonadi::StandardMailActionManager::MoveToTrash)) {
-            mActions.value(Akonadi::StandardMailActionManager::MoveToTrash)->setEnabled(itemIsSelected && canDeleteItem);
+        action = mActions.value(Akonadi::StandardMailActionManager::MoveToTrash);
+        if (action) {
+            action->setEnabled(itemIsSelected && canDeleteItem);
         }
-        if (mActions.contains(Akonadi::StandardMailActionManager::RemoveDuplicates)) {
-            mActions.value(Akonadi::StandardMailActionManager::RemoveDuplicates)->setEnabled(canDeleteItem);
+        action = mActions.value(Akonadi::StandardMailActionManager::RemoveDuplicates);
+        if (action) {
+            action->setEnabled(canDeleteItem);
         }
 
-        QAction *action = mActions.value(Akonadi::StandardMailActionManager::MarkAllMailAsRead);
+        action = mActions.value(Akonadi::StandardMailActionManager::MarkAllMailAsRead);
         if (action) {
             action->setEnabled(enableMarkAllAsRead);
         }
@@ -723,7 +726,7 @@ QAction *StandardMailActionManager::createAction(Type type)
         return d->mActions.value(type);
     }
 
-    QAction *action = Q_NULLPTR;
+    QAction *action = nullptr;
 
     switch (type) {
     case MarkMailAsRead:
@@ -928,11 +931,7 @@ void StandardMailActionManager::createAllActions()
 
 QAction *StandardMailActionManager::action(Type type) const
 {
-    if (d->mActions.contains(type)) {
-        return d->mActions.value(type);
-    }
-
-    return 0;
+    return d->mActions.value(type);
 }
 
 QAction *StandardMailActionManager::action(StandardActionManager::Type type) const
